@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 
 # Builtin
@@ -525,7 +524,13 @@ def correlations(
             ind = np.argsort(data0[ioki])
 
             # ignore constant arrays
-            if np.allclose(datai[ioki], np.mean(datai[ioki])):
+            c0 = (
+                np.allclose(datai[ioki], np.mean(datai[ioki]))
+                and np.allclose(
+                    np.log10(datai[ioki]), np.log10(np.mean(datai[ioki]))
+                )
+            )
+            if c0:
                 continue
 
             # get correlation coefs
@@ -551,7 +556,9 @@ def correlations(
                 if k0 == ref:
                     datai = ddata[k1]['data']
                 else:
-                    datai[...] = ddata[k1]['data'].reshape(v0['reshape'])
+                    datai[...] = ddata[k1]['data'].reshape(
+                        dcross[rr]['reshape'],
+                    )
 
                 # Only keep finite values
                 ioki = iok & np.isfinite(datai)
@@ -907,56 +914,56 @@ def _get_tcom(
 #############################################
 
 
-def fit_1d(data, x=None, axis=None, Type=None, func=None,
-           dTypes=None, **kwdargs):
+# def fit_1d(data, x=None, axis=None, Type=None, func=None,
+           # dTypes=None, **kwdargs):
 
-    lc = [Type is not None, func is not None]
-    assert np.sum(lc) == 1
+    # lc = [Type is not None, func is not None]
+    # assert np.sum(lc) == 1
 
-    if lc[0]:
+    # if lc[0]:
 
-        # Pre-defined models dict
-        # ------------------------
+        # # Pre-defined models dict
+        # # ------------------------
 
-        _DTYPES = {'staircase': _fit1d_staircase}
+        # _DTYPES = {'staircase': _fit1d_staircase}
 
-        # Use a pre-defined model
-        # ------------------------
+        # # Use a pre-defined model
+        # # ------------------------
 
-        if dTypes is None:
-            dTypes = _DTYPES
+        # if dTypes is None:
+            # dTypes = _DTYPES
 
-        if Type not in dTypes.keys():
-            msg = "Chosen Type not available:\n"
-            msg += "    - provided: {}\n".format(Type)
-            msg += "    - Available: {}".format(list(dTypes.keys()))
-            raise Exception(msg)
+        # if Type not in dTypes.keys():
+            # msg = "Chosen Type not available:\n"
+            # msg += "    - provided: {}\n".format(Type)
+            # msg += "    - Available: {}".format(list(dTypes.keys()))
+            # raise Exception(msg)
 
-        dout = dTypes[Type](data, x=x, axis=axis, **kwdargs)
+        # dout = dTypes[Type](data, x=x, axis=axis, **kwdargs)
 
-    else:
+    # else:
 
-        # Use a user-provided model
-        # -------------------------
+        # # Use a user-provided model
+        # # -------------------------
 
-        dout = func(data, x=x, axis=axis, **kwdargs)
+        # dout = func(data, x=x, axis=axis, **kwdargs)
 
-    return dout
+    # return dout
 
 
-# -------------------------------------------
-#       1d fit models
-# -------------------------------------------
+# # -------------------------------------------
+# #       1d fit models
+# # -------------------------------------------
 
 
-def _fit1d_staircase(data, x=None, axis=None):
-    """ Model data as a staircase (ramps + plateaux)
+# def _fit1d_staircase(data, x=None, axis=None):
+    # """ Model data as a staircase (ramps + plateaux)
 
-    Return a the fitted parameters as a dict:
-        {'plateaux': {'plateaux': {'Dt': (2,N) np.ndarray
-                                   '':
-                                    }}
-        - to be discussed.... ?
+    # Return a the fitted parameters as a dict:
+        # {'plateaux': {'plateaux': {'Dt': (2,N) np.ndarray
+                                   # '':
+                                    # }}
+        # - to be discussed.... ?
 
-    """
-    pass
+    # """
+    # pass
